@@ -1,5 +1,5 @@
 import pyaudio
-import numpy
+import numpy as np
 from logging import getLogger
 logger = getLogger('pyscab.'+__name__)
 
@@ -26,18 +26,20 @@ class CallbackParams(object):
         self.format = None
         self.time = None
         self.n_ch = None
+        self.data_callback = None
 
 callback_params = CallbackParams()
 
 def callback(in_data, frame_count, time_info, status, p=callback_params):
-    data = numpy.zeros((frame_count, p.n_ch), dtype=p.format)
+    #data = np.zeros((frame_count, p.n_ch), dtype=p.format)
+    p.data_callback.fill(0)
     for idx, is_finished in enumerate(p.data_finished):
     #for idx_audio, audio in enumerate(p.data):
     #for audio in p.data:
         if is_finished is False:
             chunk = p.data[idx].read_chunk()
             for idx_ch, ch in enumerate(p.data[idx].get_ch()):
-                data[:, ch-1] += chunk[:, idx_ch]
+                p.data_callback[:, ch-1] += chunk[:, idx_ch]
         #else:
         #    p.data_finished[idx] = True
             # if all audio chunks were loaded, delete the instance
@@ -45,17 +47,22 @@ def callback(in_data, frame_count, time_info, status, p=callback_params):
             # deleted this in ver. 0.0.6, since doing this will take time and makes problem with presenting short audio with fast SOA.
             #del p.data[idx_audio]
     p.time = time_info
-    return (numpy.ravel(data, order='C'), pyaudio.paContinue)
+    return (np.ravel(p.data_callback, order='C'), pyaudio.paContinue)
 
-def get_available_devices():
+def show_devices():
     """
     print available devices connected to the computer.
     """
     pya = pyaudio.PyAudio()
     hi = HardwareInformation(pya)
     devices = hi.devices
+    #print(devices)
     for device in devices:
-        print("name : '" + str(devices[device]['name']) + "', maxOutputChannels : " + str(devices[device]['maxOutputChannels']))
+        print("%s : " %(device) + str(devices[device]))
+        print("\n")
+        #pass
+        #print(device)
+        #print("name : '" + str(devices[device]['name']) + "', maxOutputChannels : " + str(devices[device]['maxOutputChannels']))
 
 
 class HardwareInformation(object):
@@ -156,10 +163,10 @@ class AudioInterface(object):
         self.format = format
         if format.upper() == "INT16":
             self.format_pyaudio = pyaudio.paInt16
-            self.format_numpy = numpy.dtype("int16")
+            self.format_np = np.dtype("int16")
         elif format.upper() == "UINT8":
             self.format_pyaudio = pyaudio.paUInt8
-            self.format_numpy = numpy.dtype("uint8")
+            self.format_np = np.dtype("uint8")
         else:
             raise ValueError("Unknown Format : " + self.format + ". It can only take INT16 or UINT8.")
         self.frame_rate = frame_rate
@@ -170,8 +177,8 @@ class AudioInterface(object):
 
         available_devices = hardware_information.devices
         logger.debug("Audio Device '%s' was selected.", self.device_name)
-        device = available_devices[self.device_name]
-        self.device_idx = device['index']
+        self.device = available_devices[self.device_name]
+        self.device_idx = self.device['index']
         self.num_channels = n_ch
 
         self.n_ReadAudioChunk_obj = 0
@@ -184,7 +191,8 @@ class AudioInterface(object):
         callback_params.init()
         self.n_ReadAudioChunk_obj = 0
         callback_params.n_ch = self.num_channels
-        callback_params.format = self.format_numpy
+        callback_params.format = self.format_np
+        callback_params.data_callback = np.zeros((self.frames_per_buffer, self.num_channels), dtype=self.format_np)
         self.stream = self.pya.open(format=self.format_pyaudio,
                                     channels=self.num_channels,
                                     frames_per_buffer=self.frames_per_buffer,
@@ -199,7 +207,7 @@ class AudioInterface(object):
 
         Parameters
         ----------
-        data : numpy.ndarray
+        data : np.ndarray
             audio data which have a shape of (number of samples, number of channels)
         ch : list of int
             channel number of audio device to be played (start from 1)
@@ -210,7 +218,7 @@ class AudioInterface(object):
 
         >>> play(audio_data, [1])
         """
-        callback_params.data.append(ReadAudioChunk(data, self.frames_per_buffer, ch, format = self.format_numpy, idx_obj = self.n_ReadAudioChunk_obj))
+        callback_params.data.append(ReadAudioChunk(data, self.frames_per_buffer, ch, format = self.format_np, idx_obj = self.n_ReadAudioChunk_obj))
         callback_params.data_finished.append(False)
         self.n_ReadAudioChunk_obj += 1 # should be add 1 after executing appending ReadAudioChunk obj.
 
@@ -243,7 +251,7 @@ class ReadAudioChunk(object):
 
     Attributes
     ----------
-    data : numpy.ndarray
+    data : np.ndarray
         audio data.
     n_ch_data : int
         number of channels of audio data
@@ -253,26 +261,26 @@ class ReadAudioChunk(object):
         chunk size.
     ch : list of int
         channel number of device which audio data will be played.
-    format : numpy.dtype
+    format : np.dtype
         audio data format
     finished : Bool
         If True, all audio data have already been read. If False, there's remained data.
     idx_obj : int
         id of instance.
     """
-    def __init__(self, data, chunk_size, ch, volume=1.0, format = numpy.dtype("int16"), idx_obj = None):
+    def __init__(self, data, chunk_size, ch, volume=1.0, format = np.dtype("int16"), idx_obj = None):
         """
         load data with specified settings
 
         Parameteres
         ----------
-        data : numpy.ndarray
+        data : np.ndarray
             audio data.
         chunk_sixe : int
             chunk size.
         ch : list of int
             channel number of device which audio data will be played.
-        format : numpy.dtype, default=numpy.dtype('int16')
+        format : np.dtype, default=np.dtype('int16')
             audio data format
         idx_obj : int, default=None
             id of instance.
@@ -287,12 +295,12 @@ class ReadAudioChunk(object):
         #self.remained_frames = self.n_frames
         self.finished = False
         self.idx_obj = idx_obj # will be change to id
-
+        self.chunk_data = np.zeros((self.chunk_size, self.n_ch_data), dtype=self.format)
         # if mono audio will be played from multiple channel,
         # concatenate it to multiple channel matrix
         # in order to make computational load in portaudio callback function less
         while self.n_ch_data < len(self.ch):
-            self.data = numpy.hstack((self.data,self.data))
+            self.data = np.hstack((self.data,self.data))
             self.n_ch_data = self.data.shape[1]
 
     def read_chunk(self):
@@ -301,7 +309,7 @@ class ReadAudioChunk(object):
 
         Returns
         -------
-        chunk_data : numpy.ndarray
+        chunk_data : np.ndarray
             chunk data which have a shape of (chunk size, number of channels)
         """
 
@@ -309,8 +317,8 @@ class ReadAudioChunk(object):
         end = (self.current_idx*self.chunk_size)+self.chunk_size
 
         if end >= (self.n_frames-1):
-            data = numpy.zeros((self.chunk_size, self.n_ch_data), dtype=self.format)
-            data[0:(self.n_frames-start-1),:] = self.data[start:-1,:]
+            self.chunk_data.fill(0)
+            self.chunk_data[0:(self.n_frames-start-1),:] = self.data[start:-1,:]
             
             #=====================
             #This is old method.
@@ -320,16 +328,16 @@ class ReadAudioChunk(object):
             # padding zero to last block 
             #data = self.data[start:-1,:]
             #n_padding = self.chunk_size - data.shape[0]
-            #data = numpy.vstack((data, numpy.zeros((n_padding, self.n_ch_data), dtype=self.format)))
-            #data = numpy.vstack((data, numpy.zeros((n_padding, self.n_ch_data))))
+            #data = np.vstack((data, np.zeros((n_padding, self.n_ch_data), dtype=self.format)))
+            #data = np.vstack((data, np.zeros((n_padding, self.n_ch_data))))
             #self.finished = True
             #=====================
             callback_params.data_finished[self.idx_obj] = True
         else:
-            data = self.data[start:end,:]
+            self.chunk_data = self.data[start:end,:]
             #self.remained_frames -= self.chunk_size
         self.current_idx += 1
-        return data
+        return self.chunk_data
 
     def is_finished(self):
         """
